@@ -11,6 +11,7 @@ use Mojo::File;
 
 has paths => sub { {} };
 has handlers => sub { {} };
+has trace => 4;
 
 # Standard log levels
 my %LEVEL = (debug => 1, info => 2, warn => 3, error => 4, fatal => 5);
@@ -71,22 +72,29 @@ my @mon = qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec);
 my @wday = qw(Sn Mn Ts Wn Th Fr St);
 sub _format {
   my ($time, $level) = (shift, shift);
-  $level = "[$level] "
+  $level = '['.($LEVEL{$level} ? ($level =~ /^(\w)/)[0] : $level) . '] ' #"[$level] "
     if $level //= '';
   
   my ($sec,$min,$hour,$mday,$mon,$year,$wday) = localtime($time);
   $time = sprintf "%s %s %s %s:%s:%s", $wday[$wday], $mday, map(length == 1 ? "0$_" : $_, $mon[$mon], $hour, $min, $sec);
   
-  my $trace =  join " ", @{_trace()}[1..2];
+  #~ my $trace =  '['. join(" ", @{_trace()}[1..2]) .']';
   
-  return "[$time] [$trace] $level" . join "\n", @_, '';
+  return "$time $level" . join "\n", @_, '';
 }
 
 sub _trace {
   my $start = shift // 1;
-  my @frames;
-  while (my @trace = caller($start++)) { push @frames, \@trace }
-  return pop @frames;
+  my @call = caller($start);
+  return \@call
+    if @call;
+  #~ my @frames;
+  $start = 1;
+  #~ while (my @trace = caller($start++)) { push @call, \@trace }
+  #~ return pop @call;
+  while (@call = caller($start++)) { 1; }
+  #~ return $frames[4];
+  return \@call;
 }
 
 
@@ -98,6 +106,10 @@ sub _message {
   my $max     = $self->max_history_size;
   my $history = $self->history;
   my $time = time;
+  my $trace = _trace($self->trace)
+    if $self->trace;
+  unshift @_, join(":", @$trace[$$trace[0] eq 'main' ? (1,2) : (0,2)]). ' ' . shift
+    if $trace && @$trace;
   push @$history, my $msg = [$time, $level, @_];
   shift @$history while @$history > $max;
   
@@ -121,7 +133,7 @@ sub AUTOLOAD {
   
 }
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 =encoding utf8
 
@@ -133,7 +145,7 @@ I<¡ ¡ ¡ ALL GLORY TO GLORIA ! ! !>
 
 =head1 VERSION
 
-0.04
+0.06
 
 =head1 NAME
 
@@ -224,6 +236,9 @@ Hashref map level names to absolute or relative to L</"path">
   $log->error(...); # log to /var/log/error.log
   $log->info(...); # log to STDERR
 
+=head2 trace
+
+An trace level, defaults to C<4>, C<0> value will disable trace log. This value pass to C<caller()>.
 
 =head1 METHODS
 
